# (cg) Certain binaries build in this package are no longer wanted or are now 
# provided by other packages (e.g. coreutils, util-linux or passwd)
%define unwanted chfn chsh expiry groups login passwd porttime su suauth faillog logoutd nologin chgpasswd getspnam
# (cg) Some localised man pages are provided by the man-pages package rather
# than here so kill them off
# (Question: why?? See "urpmf share.*man.*/XXXX\\." where XXXX is one of the below)
%define unwanted_i18n_mans sg shadow

Name:		shadow-utils
Version:	4.4
Release:	%mkrel 1
Epoch:		2
Summary:	Utilities for managing shadow password files and user/group accounts
License:	BSD
Group:		System/Base
URL:		http://pkg-shadow.alioth.debian.org/
Source0:	http://pkg-shadow.alioth.debian.org/releases/shadow-%{version}.tar.xz
Source1:	shadow-970616.login.defs
Source2:	shadow-970616.useradd
Source3:	adduser.8
Source4:	pwunconv.8
Source5:	grpconv.8
Source6:	grpunconv.8
Source8:	user-group-mod.pamd
Source9:	chpasswd-newusers.pamd
Source10:	chage-chfn-chsh.pamd
Patch2:		shadow-4.1.5.1-rpmsave.patch
Patch4:		shadow-4.1.4.2-dotinname.patch
Patch10:	shadow-4.1.5.1-tcb-build.patch
Patch11: 	shadow-4.4-avx-owl-crypt_gensalt.patch
Patch12: 	shadow-4.4_fix_snprintf_argument.patch
Patch13: 	shadow-4.3.1-defaults-regression.patch
BuildRequires:	gettext-devel
BuildRequires:  automake
BuildRequires:	pam-devel
BuildRequires:	glibc-crypt_blowfish-devel
BuildRequires:	pam_userpass-devel
Requires:	setup >= 2.7.12-2
Requires:	pam_userpass
Requires(post):	sed
Obsoletes:	adduser, newgrp
Provides: 	adduser, newgrp
Provides:	/usr/sbin/useradd
Provides:	/usr/sbin/groupadd
Provides:	/usr/sbin/userdel
Provides:	/usr/sbin/groupdel
Conflicts:	msec < 0.47
Conflicts:	util-linux-ng < 2.13.1-6

%description
The shadow-utils package includes the necessary programs for
converting UNIX password files to the shadow password format, plus
programs for managing user and group accounts.  The pwconv command
converts passwords to the shadow password format.  The pwunconv command
unconverts shadow passwords and generates an npasswd file (a standard
UNIX password file).  The pwck command checks the integrity of
password and shadow files.  The lastlog command prints out the last
login times for all users.  The useradd, userdel and usermod commands
are used for managing user accounts.  The groupadd, groupdel and
groupmod commands are used for managing group accounts.

%prep
%setup -q -n shadow-%{version}
%autopatch -p1

%build
libtoolize --copy --force; aclocal; autoconf; automake --add-missing
%serverbuild
CFLAGS="%{optflags} -DEXTRA_CHECK_HOME_DIR" \
%configure2_5x \
        --disable-shared \
        --with-libpam \
        --without-libcrack \
        --with-group-name-max-length=32
%make_build
# because of the extra po file added manually
make -C po update-gmo

%install
%make_install gnulocaledir=%{buildroot}/%{_datadir}/locale MKINSTALLDIRS=`pwd`/mkinstalldirs

install -d -m 750 %{buildroot}%{_sysconfdir}/default
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/login.defs
install -m 0600 %{SOURCE2} %{buildroot}%{_sysconfdir}/default/useradd


ln -s useradd %{buildroot}%_sbindir/adduser
install -m644 %SOURCE3 %{buildroot}%_mandir/man8/
install -m644 %SOURCE4 %{buildroot}%_mandir/man8/
install -m644 %SOURCE5 %{buildroot}%_mandir/man8/
install -m644 %SOURCE6 %{buildroot}%_mandir/man8/
perl -pi -e "s/encrpted/encrypted/g" %{buildroot}%{_mandir}/man8/newusers.8

# add pam support files
rm -rf %{buildroot}/etc/pam.d/
mkdir -p %{buildroot}/etc/pam.d/
install -m 0600 %{SOURCE8} %{buildroot}/etc/pam.d/user-group-mod
install -m 0600 %{SOURCE9} %{buildroot}/etc/pam.d/chpasswd-newusers
install -m 0600 %{SOURCE10} %{buildroot}/etc/pam.d/chage-chfn-chsh

pushd %{buildroot}/etc/pam.d
    for f in chpasswd newusers; do
        ln -s chpasswd-newusers ${f}
    done
    for f in chage; do
        # chfn and chsh are built without pam support in util-linux-ng
        ln -s chage-chfn-chsh ${f}
    done
    for f in groupadd groupdel groupmod useradd userdel usermod; do
        ln -s user-group-mod ${f}
    done
popd

# (cg) Remove unwanted binaries (and their corresponding man pages)
for unwanted in %{unwanted}; do
  rm -f %{buildroot}{%{_bindir},%{_sbindir}}/$unwanted
  rm -f %{buildroot}%{_mandir}/{,{??,??_??}/}man*/$unwanted.[[:digit:]]*
done

# (cg) Remove man pages provided by the "man-pages" package...
for unwanted in %{unwanted_i18n_mans}; do
  rm -f %{buildroot}%{_mandir}/{??,??_??}/man*/$unwanted.[[:digit:]]*
done

# (cg) Find all localised man pages
find %{buildroot}%{_mandir} -depth -type d -empty -delete
%find_lang shadow
for dir in $(ls -1d %{buildroot}%{_mandir}/{??,??_??}) ; do
  dir=$(echo $dir | sed -e "s|^%{buildroot}||")
  lang=$(basename $dir)
  echo "%%lang($lang) $dir/man*/*" >> shadow.lang
done


%triggerin -p <lua> -- %{name} <= %{version}-%{release}
shadow_lock = "/etc/shadow.lock"
st = posix.stat(shadow_lock)
if st and st.type == "regular" and st.size == 0 then
  os.remove(shadow_lock)
end

%post
# remove tcb and use sha512
sed -i 's/^CRYPT_PREFIX.*/ENCRYPT_METHOD SHA512/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^USE_TCB[ \t]+yes)/#USE_TCB                 yes/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^TCB_AUTH_GROUP[ \t]+yes)/#TCB_AUTH_GROUP          yes/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^TCB_SYMLINKS[ \t]+yes)/#TCB_SYMLINKS          yes/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^USE_TCB[ \t]+no)/#USE_TCB                 no/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^TCB_AUTH_GROUP[ \t]+no)/#TCB_AUTH_GROUP          no/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^TCB_SYMLINKS[ \t]+no)/#TCB_SYMLINKS          no/g' %{_sysconfdir}/login.defs



%files -f shadow.lang
%doc doc/HOWTO NEWS
%doc doc/WISHLIST doc/README.platforms
%attr(0640,root,shadow)	%config(noreplace) %{_sysconfdir}/login.defs
%attr(0600,root,root)	%config(noreplace) %{_sysconfdir}/default/useradd
%{_bindir}/sg
%attr(2711,root,shadow) %{_bindir}/chage
%attr(4711,root,root)   %{_bindir}/gpasswd
%attr(4711,root,root)   %{_bindir}/newgidmap
%attr(4711,root,root)   %{_bindir}/newgrp
%attr(4711,root,root)   %{_bindir}/newuidmap
%{_bindir}/lastlog
%{_sbindir}/adduser
%{_sbindir}/user*
%{_sbindir}/group*
%{_sbindir}/grpck
%{_sbindir}/pwck
%{_sbindir}/*conv
%{_sbindir}/chpasswd
%{_sbindir}/newusers
%{_sbindir}/vipw
%{_sbindir}/vigr
%{_mandir}/man1/chage.1*
%{_mandir}/man1/newgidmap.1*
%{_mandir}/man1/newgrp.1*
%{_mandir}/man1/newuidmap.1*
%{_mandir}/man1/sg.1*
%{_mandir}/man1/gpasswd.1*
%{_mandir}/man3/shadow.3*
%{_mandir}/man5/gshadow.5*
%{_mandir}/man5/login.defs.5*
%{_mandir}/man5/shadow.5*
%{_mandir}/man5/subgid.5*
%{_mandir}/man5/subuid.5*
%{_mandir}/man8/adduser.8*
%{_mandir}/man8/group*.8*
%{_mandir}/man8/user*.8*
%{_mandir}/man8/pwck.8*
%{_mandir}/man8/grpck.8*
%{_mandir}/man8/chpasswd.8*
%{_mandir}/man8/newusers.8*
%{_mandir}/man8/vipw.8*
%{_mandir}/man8/vigr.8*
%{_mandir}/man8/*conv.8*
%{_mandir}/man8/lastlog.8*
%attr(640,root,shadow) %config(noreplace) /etc/pam.d/chage-chfn-chsh
/etc/pam.d/chage
%attr(640,root,shadow) %config(noreplace) /etc/pam.d/chpasswd-newusers 
/etc/pam.d/chpasswd
/etc/pam.d/newusers
%attr(640,root,shadow) %config(noreplace) /etc/pam.d/user-group-mod
/etc/pam.d/useradd
/etc/pam.d/userdel
/etc/pam.d/usermod
/etc/pam.d/groupadd
/etc/pam.d/groupdel
/etc/pam.d/groupmod



%changelog
* Mon Jan 23 2017 mrambo3501 <mrambo3501> 2:4.4-1.mga6
+ Revision: 1083246
- update to version 4.4 to fix CVE-2016-625[12]
- remove shadow-perms patch applied upstream
- modify gensalt patch to work with new version
- add patch to fix compile error on new version
- add fedora patch to fix user defaults regression

* Sat Sep 24 2016 luigiwalser <luigiwalser> 2:4.2.1-12.mga6
+ Revision: 1055775
- rebuild for failed upload

* Thu Aug 04 2016 philippem <philippem> 2:4.2.1-11.mga6
+ Revision: 1044453
- rebuild for new pam

* Sun Jul 31 2016 philippem <philippem> 2:4.2.1-10.mga6
+ Revision: 1044162
- add post to be sure to remove tcb and use sha512
- remove shadow.lock

* Fri Jul 15 2016 philippem <philippem> 2:4.2.1-9.mga6
+ Revision: 1042233
- don't rely on tcb mga#18930, mga#17504

* Fri Feb 12 2016 umeabot <umeabot> 2:4.2.1-8.mga6
+ Revision: 959009
- Mageia 6 Mass Rebuild

* Fri Aug 21 2015 tmb <tmb> 2:4.2.1-7.mga6
+ Revision: 867887
- rebuild for new gcc

* Wed Aug 12 2015 tv <tv> 2:4.2.1-6.mga6
+ Revision: 863392
- use SHA512 to encrypt password

* Wed Oct 15 2014 umeabot <umeabot> 2:4.2.1-5.mga5
+ Revision: 741584
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2:4.2.1-4.mga5
+ Revision: 689130
- Mageia 5 Mass Rebuild

* Tue Sep 02 2014 colin <colin> 2:4.2.1-3.mga5
+ Revision: 670860
- Increase the group name length check from 16->32 (matches fedora)

* Sun Jul 27 2014 colin <colin> 2:4.2.1-2.mga5
+ Revision: 657627
- Switch system uid boundary to 1000+

* Wed May 14 2014 luigiwalser <luigiwalser> 2:4.2.1-1.mga5
+ Revision: 622794
- 4.2.1
- fix source URL
- explicitly list (and tighten) gpasswd permissions due to SUID
- add newgidmap and newuidmap commands to files list
- add newgidmap, newuidmap, subgid, and subuid man pages to files list

* Wed May 14 2014 luigiwalser <luigiwalser> 2:4.1.5.1-7.mga5
+ Revision: 622783
- do not accidentally delete login.defs man page (mga#13377)

* Fri Oct 18 2013 umeabot <umeabot> 2:4.1.5.1-6.mga4
+ Revision: 518318
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 2:4.1.5.1-5.mga3
+ Revision: 381957
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 06 2012 rtp <rtp> 2:4.1.5.1-4.mga3
+ Revision: 327373
- change chpasswd pam configuration to make it work again.
  Main point is to remove the pam_userpass line which has no chance
  to work since pam_userpass is not supported by chpasswd.

* Sat Dec 01 2012 lmenut <lmenut> 2:4.1.5.1-3.mga3
+ Revision: 324062
- Change and unify default paths:
  - remove /(s)bin after UsrMove
  - add /usr/local/(s)bin

* Tue Nov 20 2012 lmenut <lmenut> 2:4.1.5.1-2.mga3
+ Revision: 319884
- Change and unify default paths:
  - remove /(s)bin after UsrMove
  - add /usr/local/(s)bin

* Tue Jul 17 2012 colin <colin> 2:4.1.5.1-1.mga3
+ Revision: 271844
- Promote from testing to main repository

* Thu Jul 12 2012 colin <colin> 2:4.1.5.1-0.1.mga3
+ Revision: 270393
- New version: 4.1.5.1
- Drop outdated local Dutch translation
- Drop binaries we do not want that are shipped elsewhere
- Package manpages from all locales
- Rediff patches
- Drop TCB patch in favour of upstream TCB support now included
- Write patch to fix upstream TCB build problems
- Drop upstream applied patch (groupmod-username)

* Sun Jan 09 2011 tmb <tmb> 2:4.1.4.2-9.mga1
+ Revision: 3733
- imported package shadow-utils

